==> haskell-wai-app-static-3.1.9-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-app-static
version:              3.1.9
visibility:           public
id:                   wai-app-static-3.1.9-4daf7oflOlYE7wrbAm9uFD
key:                  wai-app-static-3.1.9-4daf7oflOlYE7wrbAm9uFD
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/web-application-interface
synopsis:             WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.

category:             Web, Yesod
abi:                  b4384143974948eea98477893f1a57d8
exposed:              True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.CmdLine
    WaiAppStatic.Listing WaiAppStatic.Storage.Embedded
    WaiAppStatic.Storage.Filesystem WaiAppStatic.Types

hidden-modules:
    Util WaiAppStatic.Storage.Embedded.Runtime
    WaiAppStatic.Storage.Embedded.TH

import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-app-static-3.1.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-app-static-3.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-static
hs-libraries:         HSwai-app-static-3.1.9-4daf7oflOlYE7wrbAm9uFD
depends:
    base-4.16.4.0 blaze-html-0.9.2.0-HYtvWoJVRy9EXNTTB6ufVU
    blaze-markup-0.8.3.0-1JYg1oSitB7In5jCs8fiQu bytestring-0.11.4.0
    containers-0.6.5.1 crypton-0.34-F7ErbNubRpgBlMs6gjJlRT
    directory-1.3.6.2 file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND
    filepath-1.4.2.2 http-date-0.0.11-KAouXuiv5Ye4A3ViJGjy2x
    http-types-0.12.4-IK3jZB6tw6k2KWf3RXsYsl
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    mime-types-0.1.2.0-4X5b6Sz1aAM6TugVqfWYtQ
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7
    optparse-applicative-0.17.1.0-FEdHU4ERawH5ZWhC4bBeG0
    template-haskell-2.18.0.0 text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 unix-compat-0.7.2-GF6nRFHS9lJCc08eWtx5Md
    unordered-containers-0.2.20-FlJ58vN39MpAJvDCdrVy2C
    wai-3.2.4-7wDTXFXmYYd6TVujdrRhKq
    wai-extra-3.1.15-CYxc8r8Rl7oDtc9j6lrne3
    warp-3.3.30-9uYHygpbdIJ3lMcS5SD4vt
    zlib-0.6.3.0-9U5F4VPIxHO8qOYgKFnRsq

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-app-static-3.1.9-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-app-static
version:              3.1.9
visibility:           public
id:                   wai-app-static-3.1.9-508srGEEhfTEgefj0KK3fp
key:                  wai-app-static-3.1.9-508srGEEhfTEgefj0KK3fp
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/web-application-interface
synopsis:             WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.

category:             Web, Yesod
abi:                  15c08d2885590727c1fe97f3a85272ec
exposed:              True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.CmdLine
    WaiAppStatic.Listing WaiAppStatic.Storage.Embedded
    WaiAppStatic.Storage.Filesystem WaiAppStatic.Types

hidden-modules:
    Util WaiAppStatic.Storage.Embedded.Runtime
    WaiAppStatic.Storage.Embedded.TH

import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-app-static-3.1.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-app-static-3.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-static
hs-libraries:         HSwai-app-static-3.1.9-508srGEEhfTEgefj0KK3fp
depends:
    base-4.16.4.0 blaze-html-0.9.2.0-GaSrKu6gylZIYHIkWm02Ci
    blaze-markup-0.8.3.0-EKP12U2bGeIvH38eojwCH bytestring-0.11.4.0
    containers-0.6.5.1 crypton-0.34-KGQpVV0vKKZ7XKEhLuSgPQ
    directory-1.3.6.2 file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND
    filepath-1.4.2.2 http-date-0.0.11-GMfuwofWnRwJ6wlihLatSA
    http-types-0.12.4-K1BiuBnIehk6RPUQXWJDEB
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    mime-types-0.1.2.0-4X5b6Sz1aAM6TugVqfWYtQ
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7
    optparse-applicative-0.17.1.0-9B5O8ePYjUG8evKtX1T4ou
    template-haskell-2.18.0.0 text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 unix-compat-0.7.2-Kcmk3eldTBQKVrrJpCSKjS
    unordered-containers-0.2.20-1oXBHIneMBm69TPTD2tYrr
    wai-3.2.4-Izl5rpe0LrhAt7zW5A5dt7
    wai-extra-3.1.15-9qPPF331x9dLqgox6CeL4b
    warp-3.3.30-1v7QmTJCyUVLEJUaina37
    zlib-0.6.3.0-3964NViQXyCEPE6a3KJUdx

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
